==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fa/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'فیلدهای سفارشی',
    'field'		                => 'فیلد',
    'about_fieldsets_title'		=> 'درباره ی تنظیمات فیلد',
    'about_fieldsets_text'		=> 'تنظیمات فیلد به شما امکان این را می دهد که گروه های فیلدهای سفارشی ایجاد کنید که مرتبا برای انواع مدل های دارایی خاص مورد استفاده ی مجدد قرار می گیرند.',
    'custom_format'             => 'قالب سفارشی ...',
    'encrypt_field'      	        => 'مقدار این فیلد را در پایگاه داده رمزگذاری کنید',
    'encrypt_field_help'      => 'هشدار: رمزگذاری یک فیلد باعث می شود آن را جستجو نکنید.',
    'encrypted'      	        => 'رمزگذاری شده',
    'fieldset'      	        => 'تنظیمات فیلد',
    'qty_fields'      	      => 'فیلد های Qty',
    'fieldsets'      	        => 'تنظیمات فیلد',
    'fieldset_name'           => 'نام تنظیمات فیلد',
    'field_name'              => 'نام فیلد',
    'field_values'            => 'ارزشهای میدان',
    'field_values_help'       => 'گزینه های انتخابی را اضافه کنید، در هر خط. خطوط خالی به غیر از خط اول نادیده گرفته می شوند.',
    'field_element'           => 'ایجاد یک عنصر',
    'field_element_short'     => 'عنصر',
    'field_format'            => 'شکل دادن',
    'field_custom_format'     => 'شکل دادن سفارشی',
    'field_custom_format_help'     => 'این فیلد اجازه می دهد تا شما از یک عبارت منظم( regex) برای اعتبار استفاده کنید. این باید با "regex:" شروع شود - برای مثال، برای تایید اینکه یک مقدار فیلد سفارشی شامل IMEI معتبر (15 رقم عددی) است، شما از <code>regex: / ^[0-9]{15}$ /</code> استفاده کنید.',
    'required'   		          => 'نیازمندی',
    'req'   		              => 'نیازمندی',
    'used_by_models'   		    => 'استفاده شده توسط مدل ها',
    'order'   		            => 'سفارش',
    'create_fieldset'         => 'تنظیمات فیلد جدید',
    'create_field'            => 'فیلد سفارشی جدید',
    'value_encrypted'      	        => 'ارزش این فیلد در پایگاه داده رمزگذاری شده است. فقط کاربران مدیریت قادر به مشاهده مقدار رمزگشایی خواهند شد',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fa/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'فیلدهای سفارشی',
    'manage'                    => 'Manage',
    'field'		                => 'فیلد',
    'about_fieldsets_title'		=> 'درباره ی تنظیمات فیلد',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'مقدار این فیلد را در پایگاه داده رمزگذاری کنید',
    'encrypt_field_help'      => 'هشدار: رمزگذاری یک فیلد باعث می شود آن را جستجو نکنید.',
    'encrypted'      	        => 'رمزگذاری شده',
    'fieldset'      	        => 'تنظیمات فیلد',
    'qty_fields'      	      => 'فیلد های Qty',
    'fieldsets'      	        => 'تنظیمات فیلد',
    'fieldset_name'           => 'نام تنظیمات فیلد',
    'field_name'              => 'نام فیلد',
    'field_values'            => 'ارزشهای میدان',
    'field_values_help'       => 'گزینه های انتخابی را اضافه کنید، در هر خط. خطوط خالی به غیر از خط اول نادیده گرفته می شوند.',
    'field_element'           => 'ایجاد یک عنصر',
    'field_element_short'     => 'عنصر',
    'field_format'            => 'شکل دادن',
    'field_custom_format'     => 'شکل دادن سفارشی',
    'field_custom_format_help'     => 'این فیلد اجازه می دهد تا شما از یک عبارت منظم( regex) برای اعتبار استفاده کنید. این باید با "regex:" شروع شود - برای مثال، برای تایید اینکه یک مقدار فیلد سفارشی شامل IMEI معتبر (15 رقم عددی) است، شما از <code>regex: / ^[0-9]{15}$ /</code> استفاده کنید.',
    'required'   		          => 'نیازمندی',
    'req'   		              => 'نیازمندی',
    'used_by_models'   		    => 'استفاده شده توسط مدل ها',
    'order'   		            => 'سفارش',
    'create_fieldset'         => 'تنظیمات فیلد جدید',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'فیلد سفارشی جدید',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'ارزش این فیلد در پایگاه داده رمزگذاری شده است. فقط کاربران مدیریت قادر به مشاهده مقدار رمزگشایی خواهند شد',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
